@@ -1,6 +1,6 @@
 /********************************************************************************
 * ReactPhysics3D physics library, http://www.reactphysics3d.com                 *
-* Copyright (c) 2010-2022 Daniel Chappuis                                       *
+* Copyright (c) 2010-2024 Daniel Chappuis                                       *
 *********************************************************************************
 *                                                                               *
 * This software is provided 'as-is', without any express or implied warranty.   *
@@ -202,7 +202,7 @@ class HingeJointComponents : public Components {
         virtual ~HingeJointComponents() override = default;
 
         /// Add a component
-        void addComponent(Entity jointEntity, bool isSleeping, const HingeJointComponent& component);
+        void addComponent(Entity jointEntity, bool isDisabled, const HingeJointComponent& component);
 
         /// Return a pointer to a given joint
         HingeJoint* getJoint(Entity jointEntity) const;
